OsrsOptions

Struct OsrsOptions 

pub struct OsrsOptions { /* private fields */ }
Oldschool RuneScape CLI. Bugs/suggestions: https://github.com/LucasPickering/osrs-cli/issues

Implementations

Source

impl OsrsOptions

pub async fn run<O: Write>(self, output: O) -> Result<()>

Execute the command defined by this options object. This is the main entrypoint to the program. Callers can customize how the these options are parsed, then call this function to execute.

The type O defines how command output will be written. For native environments, this will be stdout, whereas for the browser it will be a string buffer (which presumably gets written to the DOM).